@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 2011-2019 Michael Goffioul
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2011-2021 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -26,7 +29,6 @@ along with Octave; see the file COPYING.  If not, see
 
 #include <QAction>
 #include <QActionEvent>
-#include <QActionGroup>
 #include <QApplication>
 #include <QClipboard>
 #include <QEvent>
@@ -50,17 +52,18 @@ along with Octave; see the file COPYING.  If not, see
 #include "Container.h"
 #include "Figure.h"
 #include "FigureWindow.h"
-#include "MouseModeActionGroup.h"
 #include "QtHandlesUtils.h"
 
+#include "gui-preferences-global.h"
+#include "qt-interpreter-events.h"
+
 #include "file-ops.h"
 #include "unwind-prot.h"
 #include "utils.h"
 #include "version.h"
 
-#include "octave-qt-link.h"
-
 #include "builtin-defun-decls.h"
+#include "interpreter.h"
 
 namespace QtHandles
 {
@@ -83,57 +86,79 @@ namespace QtHandles
     return r;
   }
 
-  Figure*
-  Figure::create (const graphics_object& go)
+  static QImage
+  pointer_to_qimage (const Matrix& cdata)
   {
-    return new Figure (go, new FigureWindow ());
+    QImage retval (cdata.rows (), cdata.columns (), QImage::Format_ARGB32);
+    QColor tmp ("White");
+    QColor black ("Black");
+    QColor white ("White");
+    for (octave_idx_type ii = 0; ii < cdata.rows (); ii++)
+      for (octave_idx_type jj = 0; jj < cdata.columns (); jj++)
+        {
+          if (cdata(ii,jj) == 1.0)
+            tmp = black;
+          else if (cdata(ii,jj) == 2.0)
+            tmp = white;
+          else
+            tmp.setAlpha (0);
+
+          retval.setPixel (jj, ii, tmp.rgba ());
+        }
+
+    return retval;
   }
 
-  Figure::Figure (const graphics_object& go, FigureWindow *win)
-    : Object (go, win), m_blockUpdates (false), m_figureToolBar (nullptr),
-      m_menuBar (nullptr), m_innerRect (), m_outerRect (),
-      m_mouseModeGroup (nullptr), m_previousHeight (0), m_resizable (true)
+  Figure*
+  Figure::create (octave::base_qobject& oct_qobj, octave::interpreter& interp,
+                  const graphics_object& go)
   {
-    m_container = new Container (win);
+    return new Figure (oct_qobj, interp, go, new FigureWindow ());
+  }
+
+  Figure::Figure (octave::base_qobject& oct_qobj, octave::interpreter& interp,
+                  const graphics_object& go, FigureWindow *win)
+    : Object (oct_qobj, interp, go, win), m_blockUpdates (false),
+      m_figureToolBar (nullptr), m_menuBar (nullptr), m_innerRect (),
+      m_outerRect (), m_previousHeight (0), m_resizable (true)
+  {
+    m_container = new Container (win, oct_qobj, interp);
     win->setCentralWidget (m_container);
 
+    connect (m_container, SIGNAL (interpeter_event (const fcn_callback&)),
+             this, SIGNAL (interpeter_event (const fcn_callback&)));
+
+    connect (m_container, SIGNAL (interpeter_event (const meth_callback&)),
+             this, SIGNAL (interpeter_event (const meth_callback&)));
+
     figure::properties& fp = properties<figure> ();
 
-    // Register for the signal that indicates when a window has moved
-    // to a different screen
-    connect (win, SIGNAL (figureWindowShown ()),
-             this, SLOT (figureWindowShown ()));
-
-    // Status bar
-    m_statusBar = win->statusBar ();
-    int boffset = 0;
-
-    // Toolbar and menubar
-    createFigureToolBarAndMenuBar ();
-    int toffset = 0;
-
-    if (fp.toolbar_is ("figure")
-        || (fp.toolbar_is ("auto") && fp.menubar_is ("figure")))
-      {
-        toffset += m_figureToolBar->sizeHint ().height ();
-        boffset += m_statusBar->sizeHint ().height ();
-      }
-    else
-      {
-        m_figureToolBar->hide ();
-        m_statusBar->hide ();
-      }
-
+    // Adjust figure position
     m_innerRect = boundingBoxToRect (fp.get_boundingbox (true));
     m_outerRect = boundingBoxToRect (fp.get_boundingbox (false));
 
-    set_geometry (m_innerRect.adjusted (0, -toffset, 0, boffset));
+    set_geometry (m_innerRect);
+
+    // Menubar
+    m_menuBar = new MenuBar (win);
+    win->setMenuBar (m_menuBar);
+    m_menuBar->addReceiver (this);
+    m_menuBar->setStyleSheet (m_menuBar->styleSheet () + global_menubar_style);
+
+
+    // Status bar
+    m_statusBar = win->statusBar ();
+    m_statusBar->setVisible (false);
+
+    if (fp.toolbar_is ("figure")
+        || (fp.toolbar_is ("auto") && fp.menubar_is ("figure")))
+      showFigureStatusBar (true);
 
     // Enable mouse tracking unconditionally
     enableMouseTracking ();
 
     // When this constructor gets called all properties are already
-    // set, even non default. We force "update" here to get things right.
+    // set, even non default.  We force "update" here to get things right.
 
     // Figure title
     update (figure::properties::ID_NUMBERTITLE);
@@ -149,12 +174,20 @@ namespace QtHandles
     // Handle resizing constraints
     update (figure::properties::ID_RESIZE);
 
+    // Custom pointer data
+    update (figure::properties::ID_POINTERSHAPECDATA);
+
     // Visibility
     update (figure::properties::ID_VISIBLE);
 
     connect (this, SIGNAL (asyncUpdate (void)),
              this, SLOT (updateContainer (void)));
 
+    // Register for the signal that indicates when a window has moved
+    // to a different screen
+    connect (win, SIGNAL (figureWindowShown ()),
+             this, SLOT (figureWindowShown ()));
+
     win->addReceiver (this);
     m_container->addReceiver (this);
   }
@@ -162,59 +195,12 @@ namespace QtHandles
   Figure::~Figure (void)
   { }
 
-  static std::string
-  mouse_mode_to_string (MouseMode mode)
-  {
-    switch (mode)
-      {
-      case NoMode:
-        return "none";
-
-      case RotateMode:
-        return "rotate";
-
-      case ZoomInMode:
-        return "zoom in";
-
-      case ZoomOutMode:
-        return "zoom out";
-
-      case PanMode:
-        return "pan";
-
-      case TextMode:
-        return "text";
-
-      default:
-        break;
-      }
-
-    return "none";
-  }
-
-  static MouseMode
-  mouse_mode_from_string (const std::string& mode)
-  {
-    if (mode == "none")
-      return NoMode;
-    else if (mode == "rotate")
-      return RotateMode;
-    else if (mode == "zoom in")
-      return ZoomInMode;
-    else if (mode == "zoom out")
-      return ZoomOutMode;
-    else if (mode == "pan")
-      return PanMode;
-    else if (mode == "text")
-      return TextMode;
-    else
-      return NoMode;
-  }
-
   QString
   Figure::fileName (void)
   {
-    gh_manager::auto_lock lock;
+    gh_manager& gh_mgr = m_interpreter.get_gh_manager ();
+
+    octave::autolock guard (gh_mgr.graphics_lock ());
 
     const figure::properties& fp = properties<figure> ();
 
@@ -226,7 +212,9 @@ namespace QtHandles
   void
   Figure::setFileName (const QString& name)
   {
-    gh_manager::auto_lock lock;
+    gh_manager& gh_mgr = m_interpreter.get_gh_manager ();
+
+    octave::autolock guard (gh_mgr.graphics_lock ());
 
     figure::properties& fp = properties<figure> ();
 
@@ -236,7 +224,9 @@ namespace QtHandles
   MouseMode
   Figure::mouseMode (void)
   {
-    gh_manager::auto_lock lock;
+    gh_manager& gh_mgr = m_interpreter.get_gh_manager ();
+
+    octave::autolock guard (gh_mgr.graphics_lock ());
 
     const figure::properties& fp = properties<figure> ();
 
@@ -251,49 +241,18 @@ namespace QtHandles
         mode += ' ' + direction;
       }
 
-    return mouse_mode_from_string (mode);
-  }
+    if (mode == "rotate")
+      return RotateMode;
+    else if (mode == "zoom in")
+      return ZoomInMode;
+    else if (mode == "zoom out")
+      return ZoomOutMode;
+    else if (mode == "pan")
+      return PanMode;
+    else if (mode == "text")
+      return TextMode;
 
-  void
-  Figure::createFigureToolBarAndMenuBar (void)
-  {
-    QMainWindow *win = qWidget<QMainWindow> ();
-
-    m_figureToolBar = win->addToolBar (tr ("Figure ToolBar"));
-    m_figureToolBar->setMovable (false);
-    m_figureToolBar->setFloatable (false);
-
-    m_mouseModeGroup = new MouseModeActionGroup (win);
-    connect (m_mouseModeGroup, SIGNAL (modeChanged (MouseMode)),
-             SLOT (setMouseMode (MouseMode)));
-    m_figureToolBar->addActions (m_mouseModeGroup->actions ());
-
-    QAction *toggle_axes = m_figureToolBar->addAction (tr ("Axes"));
-    connect (toggle_axes, SIGNAL (triggered (void)),
-             this, SLOT (toggleAxes (void)));
-
-    QAction *toggle_grid = m_figureToolBar->addAction (tr ("Grid"));
-    connect (toggle_grid, SIGNAL (triggered (void)),
-             this, SLOT (toggleGrid (void)));
-
-    QAction *auto_axes = m_figureToolBar->addAction (tr ("Autoscale"));
-    connect (auto_axes, SIGNAL (triggered (void)),
-             this, SLOT (autoAxes (void)));
-
-    m_menuBar = new MenuBar (win);
-    win->setMenuBar (m_menuBar);
-    m_menuBar->addReceiver (this);
-  }
-
-  void
-  Figure::updateFigureToolBarAndMenuBar (void)
-  {
-    if (m_mouseModeGroup)
-      {
-        m_blockUpdates = true;
-        m_mouseModeGroup->setMode (mouseMode ());
-        m_blockUpdates = false;
-      }
+    return NoMode;
   }
 
   void
@@ -307,6 +266,11 @@ namespace QtHandles
         win->setFixedSize (QSize( QWIDGETSIZE_MAX, QWIDGETSIZE_MAX));
       }
 
+    // Unlock window if it is maximized or full-screen
+    int state = win->windowState ();
+    if (state == Qt::WindowFullScreen || state == Qt::WindowMaximized)
+      win->setWindowState (Qt::WindowNoState);
+
     win->setGeometry (r);
 
     if (! m_resizable)
@@ -330,20 +294,19 @@ namespace QtHandles
     if (canvas)
       canvas->redraw ();
 
-    foreach (QFrame *frame,
-             qWidget<QWidget> ()->findChildren<QFrame*> ())
+    for (auto *qobj : qWidget<QWidget> ()->findChildren<QObject*> ())
       {
-        if (frame->objectName () == "UIPanel"
-            || frame->objectName () == "UIButtonGroup")
+        if (qobj->objectName () == "UIPanel"
+            || qobj->objectName () == "UIButtonGroup"
+            || qobj->objectName () == "UIControl"
+            || qobj->objectName () == "UITable")
           {
-            Object *obj = Object::fromQObject (frame);
+            Object *obj = Object::fromQObject (qobj);
 
             if (obj)
               obj->slotRedraw ();
           }
       }
-
-    updateFigureToolBarAndMenuBar ();
   }
 
   void
@@ -372,8 +335,10 @@ namespace QtHandles
 
     if (canvas)
       {
-        gh_manager::process_events ();
-        gh_manager::auto_lock lock;
+        gh_manager& gh_mgr = m_interpreter.get_gh_manager ();
+
+        gh_mgr.process_events ();
+        octave::autolock guard (gh_mgr.graphics_lock ());
         retval = canvas->getPixels ();
       }
 
@@ -388,7 +353,6 @@ namespace QtHandles
     if (canvas)
       canvas->blockRedraw (true);
 
-    m_menuBar->removeReceiver (this);
     m_container->removeReceiver (this);
     qWidget<FigureWindow> ()->removeReceiver (this);
   }
@@ -420,7 +384,7 @@ namespace QtHandles
           int toffset = 0;
           int boffset = 0;
 
-          foreach (QToolBar *tb, win->findChildren<QToolBar*> ())
+          for (auto *tb : win->findChildren<QToolBar*> ())
             if (! tb->isHidden ())
               toffset += tb->sizeHint ().height ();
 
@@ -445,7 +409,9 @@ namespace QtHandles
             QTimer::singleShot (0, win, SLOT (show ()));
             if (! fp.is___gl_window__ ())
               {
-                gh_manager::auto_lock lock;
+                gh_manager& gh_mgr = m_interpreter.get_gh_manager ();
+
+                octave::autolock guard (gh_mgr.graphics_lock ());
                 fp.set ("__gl_window__", "on");
               }
           }
@@ -468,18 +434,14 @@ namespace QtHandles
           }
         break;
 
+      case figure::properties::ID_MENUBAR:
       case figure::properties::ID_TOOLBAR:
         if (fp.toolbar_is ("none"))
-          showFigureToolBar (false);
+          showFigureStatusBar (false);
         else if (fp.toolbar_is ("figure"))
-          showFigureToolBar (true);
+          showFigureStatusBar (true);
         else  // "auto"
-          showFigureToolBar (fp.menubar_is ("figure"));
-        break;
-
-      case figure::properties::ID_MENUBAR:
-        if (fp.toolbar_is ("auto"))
-          showFigureToolBar (fp.menubar_is ("figure"));
+          showFigureStatusBar (fp.menubar_is ("figure"));
         break;
 
       case figure::properties::ID_KEYPRESSFCN:
@@ -487,6 +449,24 @@ namespace QtHandles
           m_container->canvas (m_handle)->clearEventMask (Canvas::KeyPress);
         else
           m_container->canvas (m_handle)->addEventMask (Canvas::KeyPress);
+        // Signal the change to uipanels as well
+        for (auto *qobj : qWidget<QWidget> ()->findChildren<QObject*> ())
+          {
+            if (qobj->objectName () == "UIPanel")
+              {
+                Object *obj = Object::fromQObject (qobj);
+
+                if (obj)
+                  {
+                    if (fp.get_keypressfcn ().isempty ())
+                      obj->innerContainer ()->canvas (m_handle)->
+                        clearEventMask (Canvas::KeyPress);
+                    else
+                      obj->innerContainer ()->canvas (m_handle)->
+                        addEventMask (Canvas::KeyPress);
+                  }
+              }
+          }
         break;
 
       case figure::properties::ID_KEYRELEASEFCN:
@@ -495,6 +475,25 @@ namespace QtHandles
         else
           m_container->canvas (m_handle)->addEventMask (Canvas::KeyRelease);
         break;
+        // Signal the change to uipanels as well
+        for (auto *qobj : qWidget<QWidget> ()->findChildren<QObject*> ())
+          {
+            if (qobj->objectName () == "UIPanel")
+              {
+                Object *obj = Object::fromQObject (qobj);
+
+                if (obj)
+                  {
+                    if (fp.get_keypressfcn ().isempty ())
+                      obj->innerContainer ()->canvas (m_handle)->
+                        clearEventMask (Canvas::KeyRelease);
+                    else
+                      obj->innerContainer ()->canvas (m_handle)->
+                        addEventMask (Canvas::KeyRelease);
+                  }
+              }
+          }
+        break;
 
       case figure::properties::ID_WINDOWSTYLE:
         if (fp.windowstyle_is ("modal"))
@@ -514,8 +513,22 @@ namespace QtHandles
 
         break;
 
+      case figure::properties::ID_POINTERSHAPECDATA:
+        m_pointer_cdata =
+          pointer_to_qimage (fp.get_pointershapecdata ().matrix_value ());
+        if (fp.get_pointer () != "custom")
+          break;
+        OCTAVE_FALLTHROUGH;
+
+      case figure::properties::ID_POINTER:
+      case figure::properties::ID_POINTERSHAPEHOTSPOT:
       case figure::properties::ID___MOUSE_MODE__:
-        m_container->canvas (m_handle)->setCursor (mouseMode ());
+      case figure::properties::ID___ZOOM_MODE__:
+        m_container->canvas (m_handle)->setCursor (mouseMode (),
+                                                   fp.get_pointer (),
+                                                   m_pointer_cdata,
+                                                   fp.get_pointershapehotspot ()
+                                                   .matrix_value());
         break;
 
       default:
@@ -526,22 +539,21 @@ namespace QtHandles
   }
 
   void
-  Figure::showFigureToolBar (bool visible)
+  Figure::showFigureStatusBar (bool visible)
   {
-    if ((! m_figureToolBar->isHidden ()) != visible)
+    if (m_statusBar
+        && (! m_statusBar->isHidden ()) != visible)
       {
-        int dy1 = m_figureToolBar->sizeHint ().height ();
-        int dy2 = m_statusBar->sizeHint ().height ();
+        int dy = m_statusBar->sizeHint ().height ();
         QRect r = qWidget<QWidget> ()->geometry ();
 
         if (! visible)
-          r.adjust (0, dy1, 0, -dy2);
+          r.adjust (0, 0, 0, -dy);
         else
-          r.adjust (0, -dy1, 0, dy2);
+          r.adjust (0, 0, 0, dy);
 
         m_blockUpdates = true;
         set_geometry (r);
-        m_figureToolBar->setVisible (visible);
         m_statusBar->setVisible (visible);
         m_blockUpdates = false;
 
@@ -552,7 +564,9 @@ namespace QtHandles
   void
   Figure::updateFigureHeight (int dh)
   {
-    gh_manager::auto_lock lock;
+    gh_manager& gh_mgr = m_interpreter.get_gh_manager ();
+
+    octave::autolock guard (gh_mgr.graphics_lock ());
     graphics_object go = object ();
 
     if (go.valid_object () && dh != 0)
@@ -578,20 +592,19 @@ namespace QtHandles
                                 .arg (pt(1), 0, 'g', 5));
   }
 
+  void
+  Figure::do_connections (const QObject *receiver, const QObject* /* emitter */)
+  {
+    Object::do_connections (receiver);
+    Object::do_connections (receiver, m_container->canvas (m_handle));
+  }
+
   QWidget*
   Figure::menu (void)
   {
     return qWidget<QMainWindow> ()->menuBar ();
   }
 
-  struct UpdateBoundingBoxData
-  {
-    Matrix m_bbox;
-    bool m_internal;
-    graphics_handle m_handle;
-    Figure *m_figure;
-  };
-
   void
   Figure::updateBoundingBox (bool internal, int flags)
   {
@@ -646,8 +659,8 @@ namespace QtHandles
 
     figure::properties& fp = properties<figure> ();
 
-    gh_manager::post_set (m_handle, prop, fp.bbox2position (bb), false,
-                          prop == "position");
+    emit gh_set_event (m_handle, prop, fp.bbox2position (bb), false,
+                       prop == "position");
   }
 
   bool
@@ -659,7 +672,11 @@ namespace QtHandles
         if (xevent->type () == QEvent::MouseButtonPress)
           {
             figure::properties& fp = properties<figure> ();
-            graphics_object root = gh_manager::get_object (0);
+
+            gh_manager& gh_mgr = m_interpreter.get_gh_manager ();
+
+            graphics_object root = gh_mgr.get_object (0);
+
             if (fp.get_handlevisibility () == "on")
               root.set ("currentfigure",
                         fp.get___myhandle__ ().as_octave_value ());
@@ -688,7 +705,7 @@ namespace QtHandles
               {
               case QEvent::Close:
                 xevent->ignore ();
-                gh_manager::post_callback (m_handle, "closerequestfcn");
+                emit gh_callback_event (m_handle, "closerequestfcn");
                 return true;
 
               default:
@@ -707,6 +724,8 @@ namespace QtHandles
       {
         if (watched == m_container)
           {
+            gh_manager& gh_mgr = m_interpreter.get_gh_manager ();
+
             switch (xevent->type ())
               {
               case QEvent::Resize:
@@ -717,7 +736,7 @@ namespace QtHandles
                 if (dynamic_cast<QChildEvent *> (xevent)->child
                     ()->isWidgetType())
                   {
-                    gh_manager::auto_lock lock;
+                    octave::autolock guard (gh_mgr.graphics_lock ());
                     update (figure::properties::ID_TOOLBAR);
 
                     enableMouseTracking ();
@@ -728,7 +747,7 @@ namespace QtHandles
                 if (dynamic_cast<QChildEvent *> (xevent)->child
                     ()->isWidgetType())
                   {
-                    gh_manager::auto_lock lock;
+                    octave::autolock guard (gh_mgr.graphics_lock ());
                     update (figure::properties::ID_TOOLBAR);
                   }
                 break;
@@ -779,35 +798,19 @@ namespace QtHandles
   }
 
   void
-  Figure::setMouseMode (MouseMode mode)
-  {
-    if (m_blockUpdates)
-      return;
-
-    gh_manager::auto_lock lock;
-
-    figure::properties& fp = properties<figure> ();
-
-    fp.set___mouse_mode__ (mouse_mode_to_string (mode));
-
-    Canvas *canvas = m_container->canvas (m_handle);
-
-    if (canvas)
-      canvas->setCursor (mode);
-  }
-
-  void
-  Figure::addCustomToolBar (QToolBar *bar, bool visible)
+  Figure::addCustomToolBar (QToolBar *bar, bool visible, bool isdefault)
   {
     QMainWindow *win = qWidget<QMainWindow> ();
 
+    if (isdefault)
+      m_figureToolBar = bar;
+
     if (! visible)
       win->addToolBar (bar);
     else
       {
         QSize sz = bar->sizeHint ();
         QRect r = win->geometry ();
-        //qDebug () << "Figure::addCustomToolBar:" << r;
 
         r.adjust (0, -sz.height (), 0, 0);
 
@@ -817,7 +820,6 @@ namespace QtHandles
         win->addToolBar (bar);
         m_blockUpdates = false;
 
-        //qDebug () << "Figure::addCustomToolBar:" << win->geometry ();
         updateBoundingBox (false);
       }
   }
@@ -852,33 +854,6 @@ namespace QtHandles
     redraw ();
   }
 
-  void
-  Figure::toggleAxes (void)
-  {
-    Canvas *canvas = m_container->canvas (m_handle);
-
-    if (canvas)
-      canvas->toggleAxes (m_handle);
-  }
-
-  void
-  Figure::toggleGrid (void)
-  {
-    Canvas *canvas = m_container->canvas (m_handle);
-
-    if (canvas)
-      canvas->toggleGrid (m_handle);
-  }
-
-  void
-  Figure::autoAxes (void)
-  {
-    Canvas *canvas = m_container->canvas (m_handle);
-
-    if (canvas)
-      canvas->autoAxes (m_handle);
-  }
-
   void
   Figure::figureWindowShown ()
   {
@@ -886,14 +861,15 @@ namespace QtHandles
     QWindow* window = qWidget<QMainWindow> ()->windowHandle ();
     QScreen* screen = window->screen ();
 
-    gh_manager::auto_lock lock;
+    gh_manager& gh_mgr = m_interpreter.get_gh_manager ();
+
+    octave::autolock guard (gh_mgr.graphics_lock ());
 
     figure::properties& fp = properties<figure> ();
     fp.set___device_pixel_ratio__ (screen->devicePixelRatio ());
 
     connect (window, SIGNAL (screenChanged (QScreen*)),
              this, SLOT (screenChanged (QScreen*)));
-
 #endif
   }
 
@@ -901,7 +877,9 @@ namespace QtHandles
   Figure::screenChanged (QScreen* screen)
   {
 #if defined (HAVE_QSCREEN_DEVICEPIXELRATIO)
-    gh_manager::auto_lock lock;
+    gh_manager& gh_mgr = m_interpreter.get_gh_manager ();
+
+    octave::autolock guard (gh_mgr.graphics_lock ());
 
     figure::properties& fp = properties<figure> ();
     double old_dpr = fp.get___device_pixel_ratio__ ();
@@ -911,9 +889,11 @@ namespace QtHandles
         fp.set___device_pixel_ratio__ (new_dpr);
 
         // For some obscure reason, changing the __device_pixel_ratio__ property
-        // from the GUI thread does not necessarily trigger a redraw. Force it.
+        // from the GUI thread does not necessarily trigger a redraw.  Force it.
         redraw ();
       }
+#else
+    octave_unused_parameter (screen);
 #endif
   }
 
@@ -923,7 +903,7 @@ namespace QtHandles
     // Enable mouse tracking on every widgets
     m_container->setMouseTracking (true);
     m_container->canvas (m_handle)->qWidget ()->setMouseTracking (true);
-    foreach (QWidget *w, m_container->findChildren<QWidget*> ())
+    for (auto *w : m_container->findChildren<QWidget*> ())
       w->setMouseTracking (true);
   }
 
