@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.7.2.  */
+/* A Bison parser, made by GNU Bison 3.7.5.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -45,11 +45,11 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
-/* Identify Bison output.  */
-#define YYBISON 1
+/* Identify Bison output, and Bison version.  */
+#define YYBISON 30705
 
-/* Bison version.  */
-#define YYBISON_VERSION "3.7.2"
+/* Bison version string.  */
+#define YYBISON_VERSION "3.7.5"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -73,7 +73,7 @@
 #define yynerrs         octave_tex_nerrs
 
 /* First part of user prologue.  */
-#line 26 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 26 "../libinterp/corefcn/oct-tex-parser.yy"
 
 
 #define YYDEBUG 1
@@ -146,7 +146,7 @@ extern int octave_tex_lex (YYSTYPE *, void *);
 extern int octave_tex_debug;
 #endif
 /* "%code requires" blocks.  */
-#line 62 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 62 "../libinterp/corefcn/oct-tex-parser.yy"
 #include <string>
 
 #line 153 "libinterp/corefcn/oct-tex-parser.cc"
@@ -181,6 +181,7 @@ extern int octave_tex_debug;
   typedef enum octave_tex_tokentype octave_tex_token_kind_t;
 #endif
 /* Token kinds.  */
+#define OCTAVE_TEX_EMPTY -2
 #define OCTAVE_TEX_EOF 0
 #define OCTAVE_TEX_error 256
 #define OCTAVE_TEX_UNDEF 257
@@ -206,7 +207,7 @@ extern int octave_tex_debug;
 #if ! defined OCTAVE_TEX_STYPE && ! defined OCTAVE_TEX_STYPE_IS_DECLARED
 union OCTAVE_TEX_STYPE
 {
-#line 65 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 65 "../libinterp/corefcn/oct-tex-parser.yy"
 
   // Leaf symbols produced by the scanner.
   char ch;
@@ -220,7 +221,7 @@ union OCTAVE_TEX_STYPE
   octave::text_element *e_base;
   octave::text_element_list *e_list;
 
-#line 224 "libinterp/corefcn/oct-tex-parser.cc"
+#line 225 "libinterp/corefcn/oct-tex-parser.cc"
 
 };
 typedef union OCTAVE_TEX_STYPE OCTAVE_TEX_STYPE;
@@ -314,6 +315,18 @@ typedef int_least16_t yytype_int16;
 typedef short yytype_int16;
 #endif
 
+/* Work around bug in HP-UX 11.23, which defines these macros
+   incorrectly for preprocessor constants.  This workaround can likely
+   be removed in 2023, as HPE has promised support for HP-UX 11.23
+   (aka HP-UX 11i v2) only through the end of 2022; see Table 2 of
+   <https://h20195.www2.hpe.com/V2/getpdf.aspx/4AA4-7673ENW.pdf>.  */
+#ifdef __hpux
+# undef UINT_LEAST8_MAX
+# undef UINT_LEAST16_MAX
+# define UINT_LEAST8_MAX 255
+# define UINT_LEAST16_MAX 65535
+#endif
+
 #if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
 typedef __UINT_LEAST8_TYPE__ yytype_uint8;
 #elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
@@ -411,9 +424,9 @@ typedef int yy_state_fast_t;
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(E) ((void) (E))
+# define YY_USE(E) ((void) (E))
 #else
-# define YYUSE(E) /* empty */
+# define YY_USE(E) /* empty */
 #endif
 
 #if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
@@ -730,7 +743,7 @@ static const yytype_int8 yypgoto[] =
   /* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
-      -1,    14,    15,    16,    17,    18,    19,    20,    21,    22,
+       0,    14,    15,    16,    17,    18,    19,    20,    21,    22,
       23,    24,    25,    26
 };
 
@@ -869,8 +882,8 @@ yy_symbol_value_print (FILE *yyo,
                        yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep, octave::text_parser_tex& parser)
 {
   FILE *yyoutput = yyo;
-  YYUSE (yyoutput);
-  YYUSE (parser);
+  YY_USE (yyoutput);
+  YY_USE (parser);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
@@ -878,7 +891,7 @@ yy_symbol_value_print (FILE *yyo,
     YYPRINT (yyo, yytoknum[yykind], *yyvaluep);
 # endif
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  YYUSE (yykind);
+  YY_USE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
@@ -992,8 +1005,8 @@ static void
 yydestruct (const char *yymsg,
             yysymbol_kind_t yykind, YYSTYPE *yyvaluep, octave::text_parser_tex& parser)
 {
-  YYUSE (yyvaluep);
-  YYUSE (parser);
+  YY_USE (yyvaluep);
+  YY_USE (parser);
   if (!yymsg)
     yymsg = "Deleting";
   YY_SYMBOL_PRINT (yymsg, yykind, yyvaluep, yylocationp);
@@ -1002,93 +1015,93 @@ yydestruct (const char *yymsg,
   switch (yykind)
     {
     case YYSYMBOL_CH: /* CH  */
-#line 95 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { }
-#line 1008 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1021 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_NUM: /* NUM  */
-#line 95 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { }
-#line 1014 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1027 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_SYM: /* SYM  */
-#line 95 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { }
-#line 1020 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1033 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_simple_string: /* simple_string  */
-#line 96 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).str); }
-#line 1026 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1039 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_symbol_element: /* symbol_element  */
-#line 96 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1032 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1045 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_font_modifier_element: /* font_modifier_element  */
-#line 96 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1038 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1051 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_fontsize_element: /* fontsize_element  */
-#line 96 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1044 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1057 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_fontname_element: /* fontname_element  */
-#line 96 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1050 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1063 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_color_element: /* color_element  */
-#line 96 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1056 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1069 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_string_element: /* string_element  */
-#line 96 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1062 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1075 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_superscript_element: /* superscript_element  */
-#line 96 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1068 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1081 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_subscript_element: /* subscript_element  */
-#line 96 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1074 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1087 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_combined_script_element: /* combined_script_element  */
-#line 96 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1080 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1093 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_string_element_list: /* string_element_list  */
-#line 96 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_list); }
-#line 1086 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1099 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_scoped_string_element_list: /* scoped_string_element_list  */
-#line 96 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_list); }
-#line 1092 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1105 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
       default:
@@ -1360,180 +1373,180 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* simple_string: CH  */
-#line 109 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 109 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.str) = new std::string (1, (yyvsp[0].ch)); }
-#line 1366 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1379 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 3: /* simple_string: simple_string CH  */
-#line 111 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 111 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyvsp[-1].str)->append (1, (yyvsp[0].ch)); (yyval.str) = (yyvsp[-1].str); }
-#line 1372 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1385 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 4: /* symbol_element: SYM  */
-#line 115 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 115 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_symbol ((yyvsp[0].sym)); }
-#line 1378 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1391 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 5: /* font_modifier_element: BF  */
-#line 119 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 119 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::bold); }
-#line 1384 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1397 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 6: /* font_modifier_element: IT  */
-#line 121 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 121 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::italic); }
-#line 1390 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1403 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 7: /* font_modifier_element: SL  */
-#line 123 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 123 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::oblique); }
-#line 1396 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1409 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 8: /* font_modifier_element: RM  */
-#line 125 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 125 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::normal); }
-#line 1402 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1415 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 9: /* fontsize_element: FONTSIZE START NUM END  */
-#line 129 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 129 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontsize ((yyvsp[-1].num)); }
-#line 1408 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1421 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 10: /* fontname_element: FONTNAME START simple_string END  */
-#line 133 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 133 "../libinterp/corefcn/oct-tex-parser.yy"
                           {
                             (yyval.e_base) = new octave::text_element_fontname (*(yyvsp[-1].str));
                             delete (yyvsp[-1].str);
                           }
-#line 1417 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1430 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 11: /* color_element: COLOR START simple_string END  */
-#line 140 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 140 "../libinterp/corefcn/oct-tex-parser.yy"
                           {
                             (yyval.e_base) = new octave::text_element_color (*(yyvsp[-1].str));
                             delete (yyvsp[-1].str);
                           }
-#line 1426 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1439 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 12: /* color_element: COLOR_RGB START NUM NUM NUM END  */
-#line 145 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 145 "../libinterp/corefcn/oct-tex-parser.yy"
                           {
                             (yyval.e_base) = new octave::text_element_color ((yyvsp[-3].num), (yyvsp[-2].num), (yyvsp[-1].num));
                           }
-#line 1434 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1447 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 13: /* string_element: simple_string  */
-#line 151 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 151 "../libinterp/corefcn/oct-tex-parser.yy"
                           {
                             (yyval.e_base) = new octave::text_element_string (*(yyvsp[0].str));
                             delete (yyvsp[0].str);
                           }
-#line 1443 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1456 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 14: /* string_element: scoped_string_element_list  */
-#line 156 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 156 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = (yyvsp[0].e_list); }
-#line 1449 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1462 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 23: /* superscript_element: SUPER CH  */
-#line 168 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 168 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_superscript ((yyvsp[0].ch)); }
-#line 1455 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1468 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 24: /* superscript_element: SUPER scoped_string_element_list  */
-#line 170 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 170 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_superscript ((yyvsp[0].e_list)); }
-#line 1461 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1474 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 25: /* superscript_element: SUPER symbol_element  */
-#line 172 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 172 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_superscript ((yyvsp[0].e_base)); }
-#line 1467 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1480 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 26: /* subscript_element: SUB CH  */
-#line 176 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 176 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_subscript ((yyvsp[0].ch)); }
-#line 1473 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1486 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 27: /* subscript_element: SUB scoped_string_element_list  */
-#line 178 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 178 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_subscript ((yyvsp[0].e_list)); }
-#line 1479 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1492 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 28: /* subscript_element: SUB symbol_element  */
-#line 180 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 180 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_subscript ((yyvsp[0].e_base)); }
-#line 1485 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1498 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 29: /* combined_script_element: subscript_element superscript_element  */
-#line 184 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 184 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_combined ((yyvsp[-1].e_base), (yyvsp[0].e_base)); }
-#line 1491 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1504 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 30: /* combined_script_element: superscript_element subscript_element  */
-#line 186 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 186 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_combined ((yyvsp[-1].e_base), (yyvsp[0].e_base)); }
-#line 1497 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1510 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 31: /* string_element_list: string_element  */
-#line 190 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 190 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_list) = new octave::text_element_list ((yyvsp[0].e_base)); }
-#line 1503 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1516 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 32: /* string_element_list: string_element_list string_element  */
-#line 192 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 192 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyvsp[-1].e_list)->push_back ((yyvsp[0].e_base)); (yyval.e_list) = (yyvsp[-1].e_list); }
-#line 1509 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1522 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 33: /* scoped_string_element_list: START string_element_list END  */
-#line 197 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 197 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_list) = (yyvsp[-1].e_list); }
-#line 1515 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1528 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 34: /* scoped_string_element_list: START END  */
-#line 199 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 199 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_list) = new octave::text_element_list (); }
-#line 1521 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1534 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 35: /* string: %empty  */
-#line 203 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 203 "../libinterp/corefcn/oct-tex-parser.yy"
                           { parser.set_parse_result (new octave::text_element_string ("")); }
-#line 1527 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1540 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 36: /* string: string_element_list  */
-#line 205 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 205 "../libinterp/corefcn/oct-tex-parser.yy"
                           { parser.set_parse_result ((yyvsp[0].e_list)); }
-#line 1533 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1546 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
 
-#line 1537 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1550 "libinterp/corefcn/oct-tex-parser.cc"
 
       default: break;
     }
@@ -1727,7 +1740,7 @@ yyreturn:
   return yyresult;
 }
 
-#line 208 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 208 "../libinterp/corefcn/oct-tex-parser.yy"
 
 
 #if defined (HAVE_PRAGMA_GCC_DIAGNOSTIC)
