@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 1995-2018 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1995-2021 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -26,8 +29,8 @@ along with Octave; see the file COPYING.  If not, see
 
 #include <cerrno>
 #include <cstdlib>
-#include <new>
 
+#include <new>
 #include <sstream>
 #include <string>
 
@@ -42,12 +45,12 @@ along with Octave; see the file COPYING.  If not, see
 #include "oct-fftw.h"
 #include "oct-locbuf.h"
 #include "oct-syscalls.h"
+#include "signal-wrappers.h"
 #include "str-vec.h"
 #include "wait-for-input.h"
 
 #include "build-env.h"
 #include "liboctinterp-build-info.h"
-#include "call-stack.h"
 #include "defaults.h"
 #include "defun.h"
 #include "error.h"
@@ -82,8 +85,8 @@ under the terms of the GNU General Public License as published by\n\
 the Free Software Foundation, either version 3 of the License, or\n\
 (at your option) any later version.\n\
 \n\
-GNU Octave is distributed in the hope that it will be useful,\n\
-but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
+GNU Octave is distributed in the hope that it will be useful, but\n\
+WITHOUT ANY WARRANTY; without even the implied warranty of\n\
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n\
 GNU General Public License for more details.\n\
 \n\
@@ -149,6 +152,28 @@ run_command_and_return_output (const std::string& cmd_str)
   return retval;
 }
 
+// Combine alloc+get in one action.
+
+static void *
+get_signal_mask (void)
+{
+  void *mask = octave_alloc_signal_mask ();
+
+  octave_get_signal_mask (mask);
+
+  return mask;
+}
+
+// Combine set+free in one action.
+
+static void
+restore_signal_mask (void *mask)
+{
+  octave_set_signal_mask (mask);
+
+  octave_free_signal_mask (mask);
+}
+
 enum system_exec_type { et_sync, et_async };
 
 DEFUN (system, args, nargout,
@@ -159,17 +184,11 @@ DEFUN (system, args, nargout,
 @deftypefnx {} {[@var{status}, @var{output}] =} system (@dots{})
 Execute a shell command specified by @var{string}.
 
-If the optional argument @var{type} is @qcode{"async"}, the process is
-started in the background and the process ID of the child process is
-returned immediately.  Otherwise, the child process is started and Octave
-waits until it exits.  If the @var{type} argument is omitted, it defaults to
-the value @qcode{"sync"}.
-
-If @var{system} is called with one or more output arguments, or if the
-optional argument @var{return_output} is true and the subprocess is started
+If @var{system} is called with one or more output arguments, or if the optional
+argument @var{return_output} is true and the subprocess is started
 synchronously, then the output from the command is returned as a variable.
-Otherwise, if the subprocess is executed synchronously, its output is sent
-to the standard output.  To send the output of a command executed with
+Otherwise, if the subprocess is executed synchronously, its output is sent to
+the standard output.  To send the output of a command executed with
 @code{system} through the pager, use a command like
 
 @example
@@ -190,25 +209,30 @@ printf ("%s\n", nthargout (2, "system", "cmd"));
 @end group
 @end example
 
-The @code{system} function can return two values.  The first is the
-exit status of the command and the second is any output from the
-command that was written to the standard output stream.  For example,
+If the optional argument @var{type} is @qcode{"async"}, the process is started
+in the background and the process ID of the child process is returned
+immediately.  Otherwise, the child process is started and Octave waits until it
+exits.  If the @var{type} argument is omitted, it defaults to the value
+@qcode{"sync"}.
+
+The @code{system} function can return two values.  The first is the exit status
+of the command and the second is any output from the command that was written
+to the standard output stream.  For example,
 
 @example
 [status, output] = system ("echo foo & exit 2");
 @end example
 
 @noindent
-will set the variable @code{output} to the string @samp{foo}, and the
-variable @code{status} to the integer @samp{2}.
+will set the variable @var{output} to the string @samp{foo}, and the variable
+@var{status} to the integer @samp{2}.
 
-For commands run asynchronously, @var{status} is the process id of the
-command shell that is started to run the command.
+For commands run asynchronously, @var{status} is the process id of the command
+shell that is started to run the command.
 
 The shell used for executing commands varies with operating system and is
 typically @file{/bin/sh} for UNIX systems and @nospell{@file{cmd.exe}} for
-Windows
-systems.
+Windows systems.
 @seealso{unix, dos}
 @end deftypefn */)
 {
@@ -232,9 +256,6 @@ systems.
 
   octave_value_list retval;
 
-  // FIXME: Is this unwind_protect frame needed anymore (12/16/15)?
-  octave::unwind_protect frame;
-
   bool return_output = (nargin == 1 && nargout > 1);
 
   if (nargin > 1)
@@ -260,6 +281,13 @@ systems.
     cmd_str = '"' + cmd_str + '"';
 #endif
 
+  octave::unwind_protect frame;
+
+  frame.add_fcn (restore_signal_mask, get_signal_mask ());
+
+  octave_unblock_async_signals ();
+  octave_unblock_signal_by_name ("SIGTSTP");
+
   if (type == et_async)
     retval(0) = octave_async_system_wrapper (cmd_str.c_str ());
   else if (return_output)
@@ -321,12 +349,6 @@ specified option.
 @seealso{computer}
 @end deftypefn */)
 {
-#if defined (ENABLE_DYNAMIC_LINKING)
-  bool octave_supports_dynamic_linking = true;
-#else
-  bool octave_supports_dynamic_linking = false;
-#endif
-
   static octave_scalar_map config;
   static octave_scalar_map build_env;
   static octave_scalar_map build_features;
@@ -344,10 +366,10 @@ specified option.
            { "ENABLE_64", false },
 #endif
 
-#if defined (OCTAVE_ENABLE_ATOMIC_REFCOUNT)
-           { "ENABLE_ATOMIC_REFCOUNT", true },
+#if defined (OCTAVE_ENABLE_COMMAND_LINE_PUSH_PARSER)
+           { "ENABLE_COMMAND_LINE_PUSH_PARSER", true },
 #else
-           { "ENABLE_ATOMIC_REFCOUNT", false },
+           { "ENABLE_COMMAND_LINE_PUSH_PARSER", false },
 #endif
 
 #if defined (ENABLE_DOCS)
@@ -356,12 +378,6 @@ specified option.
            { "ENABLE_DOCS", false },
 #endif
 
-#if defined (ENABLE_DYNAMIC_LINKING)
-           { "ENABLE_DYNAMIC_LINKING", true },
-#else
-           { "ENABLE_DYNAMIC_LINKING", false },
-#endif
-
 #if defined (OCTAVE_ENABLE_FLOAT_TRUNCATE)
            { "ENABLE_FLOAT_TRUNCATE", true },
 #else
@@ -461,9 +477,7 @@ specified option.
            { "CXXFLAGS", octave::build_env::CXXFLAGS },
            { "CXXPICFLAG", octave::build_env::CXXPICFLAG },
            { "DEFS", octave::build_env::DEFS },
-           { "DL_LD", octave::build_env::DL_LD },
            { "DL_LDFLAGS", octave::build_env::DL_LDFLAGS },
-           { "DL_LIBS", octave::build_env::DL_LIBS },
            { "GCC_VERSION", octave::build_env::GCC_VERSION },
            { "GXX_VERSION", octave::build_env::GXX_VERSION },
            { "EXEEXT", octave::build_env::EXEEXT },
@@ -495,7 +509,6 @@ specified option.
            { "HDF5_LIBS", octave::build_env::HDF5_LIBS },
            { "LAPACK_LIBS", octave::build_env::LAPACK_LIBS },
            { "LDFLAGS", octave::build_env::LDFLAGS },
-           { "LD_CXX", octave::build_env::LD_CXX },
            { "LD_STATIC_FLAG", octave::build_env::LD_STATIC_FLAG },
            { "LEX", octave::build_env::LEX },
            { "LEXLIB", octave::build_env::LEXLIB },
@@ -516,9 +529,6 @@ specified option.
            { "OCT_LINK_DEPS", octave::build_env::OCT_LINK_DEPS },
            { "OCT_LINK_OPTS", octave::build_env::OCT_LINK_OPTS },
            { "OPENGL_LIBS", octave::build_env::OPENGL_LIBS },
-           { "OSMESA_CPPFLAGS", octave::build_env::OSMESA_CPPFLAGS },
-           { "OSMESA_LDFLAGS", octave::build_env::OSMESA_LDFLAGS },
-           { "OSMESA_LIBS", octave::build_env::OSMESA_LIBS },
            { "PCRE_CPPFLAGS", octave::build_env::PCRE_CPPFLAGS },
            { "PCRE_LDFLAGS", octave::build_env::PCRE_LDFLAGS },
            { "PCRE_LIBS", octave::build_env::PCRE_LIBS },
@@ -533,12 +543,11 @@ specified option.
            { "QT_CPPFLAGS", octave::build_env::QT_CPPFLAGS },
            { "QT_LDFLAGS", octave::build_env::QT_LDFLAGS },
            { "QT_LIBS", octave::build_env::QT_LIBS },
+           { "QT_OPENGL_LIBS", octave::build_env::QT_OPENGL_LIBS },
            { "RANLIB", octave::build_env::RANLIB },
            { "RDYNAMIC_FLAG", octave::build_env::RDYNAMIC_FLAG },
            { "READLINE_LIBS", octave::build_env::READLINE_LIBS },
-           { "SED", octave::build_env::SED },
            { "SHARED_LIBS", octave::build_env::SHARED_LIBS },
-           { "SH_LD", octave::build_env::SH_LD },
            { "SH_LDFLAGS", octave::build_env::SH_LDFLAGS },
            { "STATIC_LIBS", octave::build_env::STATIC_LIBS },
            { "SUITESPARSECONFIG_LIBS", octave::build_env::SUITESPARSECONFIG_LIBS },
@@ -582,8 +591,6 @@ specified option.
       config.assign ("mac", octave_value (mac_system));
       config.assign ("windows", octave_value (windows_system));
 
-      config.assign ("dld", octave_value (octave_supports_dynamic_linking));
-
       octave::mach_info::float_format ff = octave::mach_info::native_float_format ();
       config.assign ("float_format",
                      octave_value (octave::mach_info::float_format_as_string (ff)));
