@@ -1,25 +1,27 @@
-/*
-
-Copyright (C) 1996-2018 John W. Eaton
-Copyright (C) 2009-2010 VZLU Prague
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1996-2021 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -27,7 +29,8 @@ along with Octave; see the file COPYING.  If not, see
 
 #include <cctype>
 
-#include <iostream>
+#include <istream>
+#include <ostream>
 #include <vector>
 
 #include "data-conv.h"
@@ -51,7 +54,6 @@ along with Octave; see the file COPYING.  If not, see
 #include "ov-re-mat.h"
 #include "ov-str-mat.h"
 #include "pr-output.h"
-#include "pt-mat.h"
 #include "utils.h"
 
 
@@ -93,7 +95,7 @@ octave_char_matrix_str::do_index_op_internal (const octave_value_list& idx,
   octave_idx_type len = idx.length ();
 
   // If we catch an indexing error in index_vector, we flag an error in
-  // index k.  Ensure it is the right value befor each idx_vector call.
+  // index k.  Ensure it is the right value before each idx_vector call.
   // Same variable as used in the for loop in the default case.
 
   octave_idx_type k = 0;
@@ -133,9 +135,7 @@ octave_char_matrix_str::do_index_op_internal (const octave_value_list& idx,
             for (k = 0; k < len; k++)
               idx_vec(k) = idx(k).index_vector ();
 
-            retval =
-              octave_value (charNDArray (matrix.index (idx_vec, resize_ok)),
-                            type);
+            retval = octave_value (charNDArray (matrix.index (idx_vec, resize_ok)), type);
           }
           break;
         }
@@ -289,7 +289,7 @@ octave_char_matrix_str::edit_display (const float_display_format&,
           std::string retval = string_value ();
 
           if (! is_sq_string ())
-            retval = undo_string_escapes (retval);
+            retval = octave::undo_string_escapes (retval);
 
           return retval;
         }
@@ -456,7 +456,7 @@ octave_char_matrix_str::load_ascii (std::istream& is)
 
 bool
 octave_char_matrix_str::save_binary (std::ostream& os,
-                                     bool& /* save_as_floats */)
+                                     bool /* save_as_floats */)
 {
   dim_vector dv = dims ();
   if (dv.ndims () < 1)
@@ -680,9 +680,8 @@ octave_char_matrix_str::load_hdf5 (octave_hdf5_id loc_id, const char *name)
     }
   else
     {
-      // This is cruft for backward compatibility and easy data
-      // importation
-      if (rank == 0) //FIXME: Does rank==0 even exist for strings in HDF5?
+      // This is cruft for backward compatibility and easy data importation
+      if (rank == 0)
         {
           // a single string:
           int slen = H5Tget_size (type_hid);
@@ -695,9 +694,8 @@ octave_char_matrix_str::load_hdf5 (octave_hdf5_id loc_id, const char *name)
             }
           else
             {
-              OCTAVE_LOCAL_BUFFER (char, s, slen);
-              // create datatype for (null-terminated) string
-              // to read into:
+              OCTAVE_LOCAL_BUFFER (char, s, slen+1);
+              // create datatype for (null-terminated) string to read into:
               hid_t st_id = H5Tcopy (H5T_C_S1);
               H5Tset_size (st_id, slen+1);
               if (H5Dread (data_hid, st_id, octave_H5S_ALL,
