@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.7.2.  */
+/* A Bison parser, made by GNU Bison 3.7.5.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -144,6 +144,7 @@ extern int octave_debug;
   typedef enum octave_tokentype octave_token_kind_t;
 #endif
 /* Token kinds.  */
+#define OCTAVE_EMPTY -2
 #define OCTAVE_EOF 0
 #define OCTAVE_error 256
 #define OCTAVE_UNDEF 257
@@ -230,7 +231,7 @@ extern int octave_debug;
 #if ! defined OCTAVE_STYPE && ! defined OCTAVE_STYPE_IS_DECLARED
 union OCTAVE_STYPE
 {
-#line 131 "/home/jwe/src/octave-stable/libinterp/parse-tree/oct-parse.yy"
+#line 139 "../libinterp/parse-tree/oct-parse.yy"
 
   int dummy_type;
 
@@ -289,7 +290,7 @@ union OCTAVE_STYPE
   octave::tree_classdef_enum_list* tree_classdef_enum_list_type;
   octave::tree_classdef_enum_block* tree_classdef_enum_block_type;
 
-#line 293 "libinterp/parse-tree/oct-parse.h"
+#line 294 "libinterp/parse-tree/oct-parse.h"
 
 };
 typedef union OCTAVE_STYPE OCTAVE_STYPE;
