@@ -1,4 +1,9 @@
-## Copyright (C) 2012-2019 John W. Eaton
+########################################################################
+##
+## Copyright (C) 2012-2021 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,14 +20,14 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {@var{prefs} =} loadprefs ()
 ## Return a structure containing all user configured preferences.
 ## @end deftypefn
 
-## Author: jwe
-
 function retval = loadprefs ()
 
   file = prefsfile ();
