@@ -1,22 +1,29 @@
 #! /bin/sh
 
-# Copyright (C) 2006-2018 David Bateman
-#
-# This file is part of Octave.
-#
-# Octave is free software: you can redistribute it and/or modify it
-# under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# Octave is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Octave; see the file COPYING.  If not, see
-# <https://www.gnu.org/licenses/>.
+########################################################################
+##
+## Copyright (C) 2006-2021 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
+##
+## This file is part of Octave.
+##
+## Octave is free software: you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
+##
+## Octave is distributed in the hope that it will be useful, but
+## WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with Octave; see the file COPYING.  If not, see
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 # Some tests are commented out because they are known to be broken!
 # Search for "# fails"
@@ -209,12 +216,7 @@ gen_specific_tests() {
 %!assert (nnz (sparse (1,1,0)), 0)
 %!assert (nnz (sparse (eye (3))*0), 0)
 %!assert (nnz (sparse (eye (3))-sparse (eye (3))), 0)
-
-%!test
-%! wdbz = warning ("query", "Octave:divide-by-zero");
-%! warning ("off", "Octave:divide-by-zero");
-%! assert (full (sparse (eye (3))/0), full (eye (3)/0));
-%! warning (wdbz.state, "Octave:divide-by-zero");
+%!assert (full (sparse (eye (3))/0), full (eye (3)/0));
 
 EOF
 }
@@ -332,7 +334,7 @@ gen_sparsesparse_elementop_tests() {
 %!assert (as+bs, sparse (af+bf))
 %!assert (as-bs, sparse (af-bf))
 %!assert (as.*bs, sparse (af.*bf))
-%!xtest assert (as./bs, sparse (af./bf), 100*eps)
+%!assert (as./bs, sparse (af./bf), 100*eps)
 %!test
 %! sv = as.^bs;
 %! fv = af.^bf;
@@ -1030,7 +1032,7 @@ cat <<EOF
 %! x = a \ b;
 %! assert (sparse (a * x), b, feps);
 %!endfunction
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! a = alpha*sprandn (10,11,0.2) + speye (10,11);
 %! f (a,[10,2],1e-10);
 %! ## Test this by forcing matrix_type, as can't get a certain
@@ -1067,32 +1069,32 @@ cat <<EOF
 %!assert (pds\xs, sparse (pdf\xs), 100*eps)
 %!test
 %! us = alpha*[[speye(10,10);sparse(1,10)],[[1,1];sparse(9,2);[1,1]]];
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! assert (us*(us\xf), xf, 100*eps);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! assert (us*(us\xs), xs, 100*eps);
 %!test
 %! pus = us(:,[2,1,3:12]);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! assert (pus*(pus\xf), xf, 100*eps);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! assert (pus*(pus\xs), xs, 100*eps);
 %!test
 %! us = alpha*[speye(11,9),[1;sparse(8,1);1;0]];
 %!testif HAVE_CXSPARSE
 %! [c,r] = qr (us, xf);
 %! assert (us\xf, r\c, 100*eps);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (us, xs);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
 %! assert (us\xs, r\c, 100*eps);
 %!test
 %! pus = us(:,[1:8,10,9]);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (pus, xf);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
 %! assert (pus\xf, r\c, 100*eps);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (pus, xs);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
 %! assert (pus\xs, r\c, 100*eps);
@@ -1110,20 +1112,20 @@ cat <<EOF
 %! ls = alpha*[speye(10,10), sparse(10,1);[1;1], sparse(2,9),[1;1]];
 %! xf = beta * ones (12,2);
 %! xs = speye (12,12);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (ls, xf);
 %! assert (ls\xf, r\c, 100*eps);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (ls, xs);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
 %! assert (ls\xs, r\c, 100*eps);
-%!testif HAVE_CXSPARSE
+%!test
 %! pls = ls(:,[1:8,10,9]);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (pls, xf);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
 %! assert (pls\xf, r\c, 100*eps);
-%!testif HAVE_UMFPACK
+%!testif HAVE_UMFPACK, HAVE_CXSPARSE
 %! [c,r] = qr (pls, xs);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
 %! assert (pls\xs, r\c, 100*eps);
